#########################################################################################################
#
# Analysis for the paper Automatic Mechanism for Measuring SUbjective Unit of Discomfort
# 2018 TUDelft
# This script will generate output: "data_prepare_automatic_mechanism_for_measuring_sUbjective_unit_of_discomfort.txt" 
#
# Required datafiles:
# a. r_data.csv 
# 
#########################################################################################################

# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#1/R/")


# Capture all the output to a file
sink("data_prepare_automatic_mechanism_for_measuring_subjective_unit_of_discomfort.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 

# if you not have one of this library, you can run this command to install your specific library
# install.packages("ez", dependencies = TRUE)
library(reshape2)
library(ez)


################################################ DATA ####################################################

# File: r_data.csv  
# This file contains several mesurements such as:
# a. SEQ (SUD score Experience Questionnaire), 7-liert scale, from 1 (strongly disagree) to 7 (strongly agree)
# b. DEQ (Dialogue Experience Questionnaire), 7-likert scale, from 1 (strongly disagree) to 7 (strongly agree)
# c. IPQ (Igroup Presence Questionnaire), 7-likert scale, from -3 (fully disagree) to +3 (fully agree)
# d. COding annotation from 3 different coders, annotate as: coder1, coder2, coder3
# obtained in the three condition during this study.
# These three conditons are:
# 1. Dialog dependent, annotate as: cond1
# 2. Speech dependent, annotate as: cond2
# 3. Context independent, annotate as: cond3


# Data fields explanation:
#
# 01. pid: participants ID number
# 02. gender: gender of  participants, coded: male = 0, female = 1
# 03. age: age of participants (years)
# 04. ipq_cond1_q1: IPQ question number 1 (sense of being there) in condition 1
# 05. ipq_cond1_q2: IPQ question number 2 (sense of VE surrounds me) in condition 1
# 06. ipq_cond1_q3: IPQ question number 3 (senses of only pictures) in condition 1
# 07. ipq_cond1_q4: IPQ question number 4 (not sense of being in virtual space) in condition 1
# 08. ipq_cond1_q5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 1
# 09. ipq_cond1_q6: IPQ question number 6 (sense of being present in VE) in condition 1
# 10. ipq_cond1_q7: IPQ question number 7 (awareness of real environtment) in condition 1
# 11. ipq_cond1_q8: IPQ question number 8 (not aware of real environtment) in condition 1
# 12. ipq_cond1_q9: IPQ question number 9 (no attention to real environtment) in condition 1
# 13. ipq_cond1_q10: IPQ question number 10 (attention captivated by VE) in condition 1
# 14. ipq_cond1_q11: IPQ question number 11 (VE real is not real/ real) in condition 1
# 15. ipq_cond1_q12: IPQ question number 12 (experience similar to real environtment) in condition 1
# 16. ipq_cond1_q13: IPQ question number 13 (VE is imagined/ real) in condition 1
# 17. ipq_cond1_q14: IPQ question number 14 (VE seemed more realistic than the real world) in condition 1

# 18. ipq_cond2_q1: IPQ question number 1 (sense of being there) in condition 2
# 19. ipq_cond2_q2: IPQ question number 2 (sense of VE surrounds me) in condition 2
# 20. ipq_cond2_q3: IPQ question number 3 (senses of only pictures) in condition 2
# 21. ipq_cond2_q4: IPQ question number 4 (not sense of being in virtual space) in condition 2
# 22. ipq_cond2_q5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 2
# 23. ipq_cond2_q6: IPQ question number 6 (sense of being present in VE) in condition 2
# 24. ipq_cond2_q7: IPQ question number 7 (awareness of real environtment) in condition 2
# 25. ipq_cond2_q8: IPQ question number 8 (not aware of real environtment) in condition 2
# 26. ipq_cond2_q9: IPQ question number 9 (no attention to real environtment) in condition 2
# 27. ipq_cond2_q10: IPQ question number 10 (attention captivated by VE) in condition 2
# 28. ipq_cond2_q11: IPQ question number 11 (VE real is not real/ real) in condition 2
# 29. ipq_cond2_q12: IPQ question number 12 (experience similar to real environtment) in condition 2
# 30. ipq_cond2_q13: IPQ question number 13 (VE is imagined/ real) in condition 2
# 31. ipq_cond2_q14: IPQ question number 14 (VE seemed more realistic than the real world) in condition 2

# 32. ipq_cond3_q1: IPQ question number 1 (sense of being there) in condition 3
# 33. ipq_cond3_q2: IPQ question number 2 (sense of VE surrounds me) in condition 3
# 34. ipq_cond3_q3: IPQ question number 3 (senses of only pictures) in condition 3
# 35. ipq_cond3_q4: IPQ question number 4 (not sense of being in virtual space) in condition 3
# 36. ipq_cond3_q5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 3
# 37. ipq_cond3_q6: IPQ question number 6 (sense of being present in VE) in condition 3
# 38. ipq_cond3_q7: IPQ question number 7 (awareness of real environtment) in condition 3
# 39. ipq_cond3_q8: IPQ question number 8 (not aware of real environtment) in condition 3
# 40. ipq_cond3_q9: IPQ question number 9 (no attention to real environtment) in condition 3
# 41. ipq_cond3_q10: IPQ question number 10 (attention captivated by VE) in condition 3
# 42. ipq_cond3_q11: IPQ question number 11 (VE real is not real/ real) in condition 3
# 43. ipq_cond3_q12: IPQ question number 12 (experience similar to real environtment) in condition 3
# 44. ipq_cond3_q13: IPQ question number 13 (VE is imagined/ real) in condition 3
# 45. ipq_cond3_q14: IPQ question number 14 (VE seemed more realistic than the real world) in condition 3
#
# 46. seq_cond1_q1: SEQ question number 1 (distracted by SUD score) in condition 1
# 47. seq_cond1_q2: SEQ question number 2 (switch between dialog and SUD Score was confusing) in condition 1
# 48. seq_cond1_q3: SEQ question number 3 (SUD score was too ofted asked) in condition 1
# 49. seq_cond1_q4: SEQ question number 4 (difficult to get back to the dialog after SUD score) in condition 1

# 50. seq_cond2_q1: SEQ question number 1 (distracted by SUD score) in condition 2
# 51. seq_cond2_q2: SEQ question number 2 (switch between dialog and SUD Score was confusing) in condition 2
# 52. seq_cond2_q3: SEQ question number 3 (SUD score was too ofted asked) in condition 2
# 53. seq_cond2_q4: SEQ question number 4 (difficult to get back to the dialog after SUD score) in condition 2
# 
# 54. seq_cond3_q1: SEQ question number 1 (distracted by SUD score) in condition 3
# 55. seq_cond3_q2: SEQ question number 2 (switch between dialog and SUD Score was confusing) in condition 3
# 56. seq_cond3_q3: SEQ question number 3 (SUD score was too ofted asked) in condition 3
# 57. seq_cond3_q4: SEQ question number 4 (difficult to get back to the dialog after SUD score) in condition 3
#
# 58. deq_cond1_speed1: DEQ question regarding dialog speed number 1 (avatar need long time too think) in condition 1
# 59. deq_cond1_speed2: DEQ question regarding dialog speed number 2 (avatar often went quiet) in condition 1
# 60. deq_cond1_speed3: DEQ question regarding dialog speed number 3 (I had to wait long time for a reaction from avatar) in condition 1
# 61. deq_cond1_speed4: DEQ question regarding dialog speed number 4 (the conversation did not runs smoothly) in condition 1
#
# 62. deq_cond1_interrupt1: DEQ question regarding dialog interuption number 1 (I was always able to finish the dialog) in condition 1
# 63. deq_cond1_interrupt1: DEQ question regarding dialog interuption number 2 (I often unable to finish the dialog) in condition 1
# 64. deq_cond1_interrupt1: DEQ question regarding dialog interuption number 3 (on occasions avatar talked before their turn) in condition 1
# 65. deq_cond1_interrupt1: DEQ question regarding dialog interuption number 4 (on occasion the avatar started talking while I was talking) in condition 1
# 66. deq_cond1_interrupt1: DEQ question regarding dialog interuption number 5 (avatar give me enough time to explain everything) in condition 1
#
# 67. deq_cond1_corloc1: DEQ question regarding dialog correctness-locally number 1 (the avatars addressed my answers) in condition 1
# 68. deq_cond1_corloc2: DEQ question regarding dialog correctness-locally number 2 (the avatars responds to my answers) in condition 1
# 69. deq_cond1_corloc3: DEQ question regarding dialog correctness-locally number 3 (I got the feeling the the avatars understood my answers) in condition 1
# 70. deq_cond1_corloc4: DEQ question regarding dialog correctness-locally number 4 (the questions had a logical order) in condition 1
#
# 71. deq_cond1_corglo1: DEQ question regarding dialog correctness-globally number 1 (the avatars rambled) in condition 1
# 72. deq_cond1_corglo2: DEQ question regarding dialog correctness-globally number 2 (the avatars asked things I had already answered) in condition 1
# 73. deq_cond1_corglo3: DEQ question regarding dialog correctness-globally number 3 (on occasion, I had to repeat myself) in condition 1
# 74. deq_cond1_corglo4: DEQ question regarding dialog correctness-globally number 4 (I dont always understood why things were asked) in condition 1
#
# 75. deq_cond1_inv1: DEQ question regarding involvment number 1 (avatar did not listen to my answer) in condition 1
# 76. deq_cond1_inv2: DEQ question regarding involvment number 2 (avatar looks acted detached) in condition 1
# 77. deq_cond1_inv3: DEQ question regarding involvment number 3 (avatar interested in my answer) in condition 1
# 78. deq_cond1_inv4: DEQ question regarding involvment number 4 (I got feeling that I was listened to) in condition 1
# 79. deq_cond1_inv5: DEQ question regarding involvment number 5 (avatar did not interested in me) in condition 1
# 
# 80. deq_cond1_sat1: DEQ question regarding satisfaction number 1 (the discussion wAS pleasant) in condition 1
# 81. deq_cond1_sat2: DEQ question regarding satisfaction number 2 (I was left with good feeling about the discussion) in condition 1
# 82. deq_cond1_sat3: DEQ question regarding satisfaction number 3 (I have experienced the question round was pleasant) in condition 1
# 83. deq_cond1_sat4: DEQ question regarding satisfaction number 4 (avatar made me nervous) in condition 1
# 84. deq_cond1_sat5: DEQ question regarding satisfaction number 5 (I did not comfortable during the question round) in condition 1
#
# 85. deq_cond1_real1: DEQ question regarding reality number 1 (I got feeling that this type of conversation could happen in real life) in condition 1
# 86. deq_cond1_real2: DEQ question regarding reality number 2 (avatar seemed natural) in condition 1
# 87. deq_cond1_real3: DEQ question regarding reality number 3 (I can imagine that this could happen to me in real life) in condition 1
# 88. deq_cond1_real4: DEQ question regarding reality number 4 (I had to adjust myself to the discussion partners) in condition 1
# 89. deq_cond1_real5: DEQ question regarding reality number 5 (avatar seemed realistic) in condition 1
#

# Dataset preparation:
dataset <- read.csv("r_data.csv")
dataset$gender <- factor(dataset$gender, levels = c(0,1), labels = c("male", "female"))
# SEQ
dataset$total_seq_cond1 <- rowSums(dataset[46:49])
dataset$total_seq_cond2 <- rowSums(dataset[50:53])
dataset$total_seq_cond3 <- rowSums(dataset[54:57])
# DEQ
dataset$total_deq_cond1 <- rowSums(dataset[58:89])
dataset$total_deq_cond2 <- rowSums(dataset[90:121])
dataset$total_deq_cond3 <- rowSums(dataset[122:153])
# IPQ
dataset$total_ipq_cond1 <- rowSums(dataset[4:17])
dataset$total_ipq_cond2 <- rowSums(dataset[18:31])
dataset$total_ipq_cond3 <- rowSums(dataset[32:45])

# Total condition 1
dataset$total_cond1_coder1 <- rowSums(dataset[c(154:158)]) 
dataset$total_cond1_coder2 <- rowSums(dataset[c(169:173)]) 
dataset$total_cond1_coder3 <- rowSums(dataset[c(184:188)]) 
# Total condition 2
dataset$total_cond2_coder1 <- rowSums(dataset[c(159:163)]) 
dataset$total_cond2_coder2 <- rowSums(dataset[c(174:178)]) 
dataset$total_cond2_coder3 <- rowSums(dataset[c(189:193)]) 
# Total condition 3
dataset$total_cond3_coder1 <- rowSums(dataset[c(164:168)]) 
dataset$total_cond3_coder2 <- rowSums(dataset[c(179:183)]) 
dataset$total_cond3_coder3 <- rowSums(dataset[c(194:198)])

# Calculate relative frequency 
# Iterate: normal, short, detail, dont, lost
# Condition 1
# coder 1
dataset$relfreq_cond1_coder1_normal <- dataset$normal_cond1_coder1/dataset$total_cond1_coder1
dataset$relfreq_cond1_coder1_short <- dataset$short_cond1_coder1/dataset$total_cond1_coder1 
dataset$relfreq_cond1_coder1_detail <- dataset$detail_cond1_coder1/dataset$total_cond1_coder1
dataset$relfreq_cond1_coder1_dont <- dataset$dont_cond1_coder1/dataset$total_cond1_coder1
dataset$relfreq_cond1_coder1_lost <- dataset$lost_cond1_coder1/dataset$total_cond1_coder1
# coder 2
dataset$relfreq_cond1_coder2_normal <- dataset$normal_cond1_coder2/dataset$total_cond1_coder2
dataset$relfreq_cond1_coder2_short <- dataset$short_cond1_coder2/dataset$total_cond1_coder2 
dataset$relfreq_cond1_coder2_detail <- dataset$detail_cond1_coder2/dataset$total_cond1_coder2
dataset$relfreq_cond1_coder2_dont <- dataset$dont_cond1_coder2/dataset$total_cond1_coder2
dataset$relfreq_cond1_coder2_lost <- dataset$lost_cond1_coder2/dataset$total_cond1_coder2
# coder 3
dataset$relfreq_cond1_coder3_normal <- dataset$normal_cond1_coder3/dataset$total_cond1_coder3
dataset$relfreq_cond1_coder3_short <- dataset$short_cond1_coder3/dataset$total_cond1_coder3
dataset$relfreq_cond1_coder3_detail <- dataset$detail_cond1_coder3/dataset$total_cond1_coder3
dataset$relfreq_cond1_coder3_dont <- dataset$dont_cond1_coder3/dataset$total_cond1_coder3
dataset$relfreq_cond1_coder3_lost <- dataset$lost_cond1_coder3/dataset$total_cond1_coder3
# Condition 2
# coder 1
dataset$relfreq_cond2_coder1_normal <- dataset$normal_cond2_coder1/dataset$total_cond2_coder1 #.
dataset$relfreq_cond2_coder1_short <- dataset$short_cond2_coder1/dataset$total_cond2_coder1
dataset$relfreq_cond2_coder1_detail <- dataset$detail_cond2_coder1/dataset$total_cond2_coder1
dataset$relfreq_cond2_coder1_dont <- dataset$dont_cond2_coder1/dataset$total_cond2_coder1
dataset$relfreq_cond2_coder1_lost <- dataset$lost_cond2_coder1/dataset$total_cond2_coder1
# coder 2
dataset$relfreq_cond2_coder2_normal <- dataset$normal_cond2_coder2/dataset$total_cond2_coder2
dataset$relfreq_cond2_coder2_short <- dataset$short_cond2_coder2/dataset$total_cond2_coder2
dataset$relfreq_cond2_coder2_detail <- dataset$detail_cond2_coder2/dataset$total_cond2_coder2
dataset$relfreq_cond2_coder2_dont <- dataset$dont_cond2_coder2/dataset$total_cond2_coder2
dataset$relfreq_cond2_coder2_lost <- dataset$lost_cond2_coder2/dataset$total_cond2_coder2
# coder 3
dataset$relfreq_cond2_coder3_normal <- dataset$normal_cond2_coder3/dataset$total_cond2_coder3
dataset$relfreq_cond2_coder3_short <- dataset$short_cond2_coder3/dataset$total_cond2_coder3 
dataset$relfreq_cond2_coder3_detail <- dataset$detail_cond2_coder3/dataset$total_cond2_coder3
dataset$relfreq_cond2_coder3_dont <- dataset$dont_cond2_coder3/dataset$total_cond2_coder3
dataset$relfreq_cond2_coder3_lost <- dataset$lost_cond2_coder3/dataset$total_cond2_coder3
# Condition 3
# coder 1
dataset$relfreq_cond3_coder1_normal <- dataset$normal_cond3_coder1/dataset$total_cond3_coder1
dataset$relfreq_cond3_coder1_short <- dataset$short_cond3_coder1/dataset$total_cond3_coder1
dataset$relfreq_cond3_coder1_detail <- dataset$detail_cond3_coder1/dataset$total_cond3_coder1
dataset$relfreq_cond3_coder1_dont <- dataset$dont_cond3_coder1/dataset$total_cond3_coder1
dataset$relfreq_cond3_coder1_lost <- dataset$lost_cond3_coder1/dataset$total_cond3_coder1
# coder 2
dataset$relfreq_cond3_coder2_normal <- dataset$normal_cond3_coder2/dataset$total_cond3_coder2
dataset$relfreq_cond3_coder2_short <- dataset$short_cond3_coder2/dataset$total_cond3_coder2
dataset$relfreq_cond3_coder2_detail <- dataset$detail_cond3_coder2/dataset$total_cond3_coder2
dataset$relfreq_cond3_coder2_dont <- dataset$dont_cond3_coder2/dataset$total_cond3_coder2
dataset$relfreq_cond3_coder2_lost <- dataset$lost_cond3_coder2/dataset$total_cond3_coder2
# coder 3
dataset$relfreq_cond3_coder3_normal <- dataset$normal_cond3_coder3/dataset$total_cond3_coder3
dataset$relfreq_cond3_coder3_short <- dataset$short_cond3_coder3/dataset$total_cond3_coder3 
dataset$relfreq_cond3_coder3_detail <- dataset$detail_cond3_coder3/dataset$total_cond3_coder3
dataset$relfreq_cond3_coder3_dont <- dataset$dont_cond3_coder3/dataset$total_cond3_coder3
dataset$relfreq_cond3_coder3_lost <- dataset$lost_cond3_coder3/dataset$total_cond3_coder3

# Average relative frequency
# Condition 1
dataset$avg_relfreq_cond1_normal <- rowMeans(dataset[c(grep("relfreq_cond1_coder1_normal", colnames(dataset)), grep("relfreq_cond1_coder2_normal", colnames(dataset)), grep("relfreq_cond1_coder3_normal", colnames(dataset)))]) #option: na.rm = TRUE
dataset$avg_relfreq_cond1_short <- rowMeans(dataset[c(grep("relfreq_cond1_coder1_short", colnames(dataset)), grep("relfreq_cond1_coder2_short", colnames(dataset)), grep("relfreq_cond1_coder3_short", colnames(dataset)))])
dataset$avg_relfreq_cond1_detail <- rowMeans(dataset[c(grep("relfreq_cond1_coder1_detail", colnames(dataset)), grep("relfreq_cond1_coder2_detail", colnames(dataset)), grep("relfreq_cond1_coder3_detail", colnames(dataset)))])
dataset$avg_relfreq_cond1_dont <- rowMeans(dataset[c(grep("relfreq_cond1_coder1_dont", colnames(dataset)), grep("relfreq_cond1_coder2_dont", colnames(dataset)), grep("relfreq_cond1_coder3_dont", colnames(dataset)))])
dataset$avg_relfreq_cond1_lost <- rowMeans(dataset[c(grep("relfreq_cond1_coder1_lost", colnames(dataset)), grep("relfreq_cond1_coder2_lost", colnames(dataset)), grep("relfreq_cond1_coder3_lost", colnames(dataset)))])
# Condition 2
dataset$avg_relfreq_cond2_normal <- rowMeans(dataset[c(grep("relfreq_cond2_coder1_normal", colnames(dataset)), grep("relfreq_cond2_coder2_normal", colnames(dataset)), grep("relfreq_cond2_coder3_normal", colnames(dataset)))])
dataset$avg_relfreq_cond2_short <- rowMeans(dataset[c(grep("relfreq_cond2_coder1_short", colnames(dataset)), grep("relfreq_cond2_coder2_short", colnames(dataset)), grep("relfreq_cond2_coder3_short", colnames(dataset)))])
dataset$avg_relfreq_cond2_detail <- rowMeans(dataset[c(grep("relfreq_cond2_coder1_detail", colnames(dataset)), grep("relfreq_cond2_coder2_detail", colnames(dataset)), grep("relfreq_cond2_coder3_detail", colnames(dataset)))])
dataset$avg_relfreq_cond2_dont <- rowMeans(dataset[c(grep("relfreq_cond2_coder1_dont", colnames(dataset)), grep("relfreq_cond2_coder2_dont", colnames(dataset)), grep("relfreq_cond2_coder3_dont", colnames(dataset)))])
dataset$avg_relfreq_cond2_lost <- rowMeans(dataset[c(grep("relfreq_cond2_coder1_lost", colnames(dataset)), grep("relfreq_cond2_coder2_lost", colnames(dataset)), grep("relfreq_cond2_coder3_lost", colnames(dataset)))])
# Condition 3
dataset$avg_relfreq_cond3_normal <- rowMeans(dataset[c(grep("relfreq_cond3_coder1_normal", colnames(dataset)), grep("relfreq_cond3_coder2_normal", colnames(dataset)), grep("relfreq_cond3_coder3_normal", colnames(dataset)))])
dataset$avg_relfreq_cond3_short <- rowMeans(dataset[c(grep("relfreq_cond3_coder1_short", colnames(dataset)), grep("relfreq_cond3_coder2_short", colnames(dataset)), grep("relfreq_cond3_coder3_short", colnames(dataset)))])
dataset$avg_relfreq_cond3_detail <- rowMeans(dataset[c(grep("relfreq_cond3_coder1_detail", colnames(dataset)), grep("relfreq_cond3_coder2_detail", colnames(dataset)), grep("relfreq_cond3_coder3_detail", colnames(dataset)))])
dataset$avg_relfreq_cond3_dont <- rowMeans(dataset[c(grep("relfreq_cond3_coder1_dont", colnames(dataset)), grep("relfreq_cond3_coder2_dont", colnames(dataset)), grep("relfreq_cond3_coder3_dont", colnames(dataset)))])
dataset$avg_relfreq_cond3_lost <- rowMeans(dataset[c(grep("relfreq_cond3_coder1_lost", colnames(dataset)), grep("relfreq_cond3_coder2_lost", colnames(dataset)), grep("relfreq_cond3_coder3_lost", colnames(dataset)))])

# write all data preparation to a new .csv files and later used to data exploration.
cat("\n\nWriting wide format data frame into file...\n\n")

data_wide_process <- dataset[, c("pid", "gender", "age",
                                 "total_seq_cond1", "total_seq_cond2", "total_seq_cond3",
                                 "total_deq_cond1", "total_deq_cond2", "total_deq_cond3",
                                 "total_ipq_cond1", "total_ipq_cond2", "total_ipq_cond3",
                                 "avg_relfreq_cond1_normal", "avg_relfreq_cond1_short", "avg_relfreq_cond1_detail", "avg_relfreq_cond1_dont", "avg_relfreq_cond1_lost",
                                 "avg_relfreq_cond2_normal", "avg_relfreq_cond2_short", "avg_relfreq_cond2_detail", "avg_relfreq_cond2_dont", "avg_relfreq_cond2_lost",
                                 "avg_relfreq_cond3_normal", "avg_relfreq_cond3_short", "avg_relfreq_cond3_detail", "avg_relfreq_cond3_dont", "avg_relfreq_cond3_lost"
                                 )]
write.csv(data_wide_process, "data_wide_process.csv", row.names = FALSE)

# prepare long data format 
cat("Writing long data format...\n\n")

############################################### FUNCTIONS ###############################################

# transform Maindata dataframe for a wide format to long format
tranformToLong <- function(mshort,idlist, measurelist,measurename)
{ 
  #mshort <- dataset[!is.na(dataset[[idlist]]),] # removes all rows that contain an NA for that DV
  msubset <- subset(mshort, select = c(idlist,measurelist))
  mlong <- melt(msubset, id=idlist, measured = measurelist)
  names(mlong) <- c("pid","condition",measurename)
  levels(mlong$condition) <- c(1, 2, 3) # re-coded the levels
  return(mlong)
}

# merge several data frames into one
merge_func <- function(x, y){
  df            <- merge(x, y, by=c("pid","condition"), all.x= FALSE, all.y= FALSE)
  rownames(df)  <- df$Row.names
  df$Row.names  <- NULL
  return(df)
}

#########################################################################################################

# Detail answer
long_coder1_detail <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder1_detail", "relfreq_cond2_coder1_detail", "relfreq_cond3_coder1_detail"), "relfreq_coder1_detail")
long_coder2_detail <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder2_detail", "relfreq_cond2_coder2_detail", "relfreq_cond3_coder2_detail"), "relfreq_coder2_detail")
long_coder3_detail <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder3_detail", "relfreq_cond2_coder3_detail", "relfreq_cond3_coder3_detail"), "relfreq_coder3_detail")
# Normal answer
long_coder1_normal <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder1_normal", "relfreq_cond2_coder1_normal", "relfreq_cond3_coder1_normal"), "relfreq_coder1_normal")
long_coder2_normal <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder2_normal", "relfreq_cond2_coder2_normal", "relfreq_cond3_coder2_normal"), "relfreq_coder2_normal")
long_coder3_normal <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder3_normal", "relfreq_cond2_coder3_normal", "relfreq_cond3_coder3_normal"), "relfreq_coder3_normal")
# Short answer
long_coder1_short <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder1_short", "relfreq_cond2_coder1_short", "relfreq_cond3_coder1_short"), "relfreq_coder1_short")
long_coder2_short <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder2_short", "relfreq_cond2_coder2_short", "relfreq_cond3_coder2_short"), "relfreq_coder2_short")
long_coder3_short <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder3_short", "relfreq_cond2_coder3_short", "relfreq_cond3_coder3_short"), "relfreq_coder3_short")
# Dont know answer
long_coder1_dont <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder1_dont", "relfreq_cond2_coder1_dont", "relfreq_cond3_coder1_dont"), "relfreq_coder1_dont")
long_coder2_dont <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder2_dont", "relfreq_cond2_coder2_dont", "relfreq_cond3_coder2_dont"), "relfreq_coder2_dont")
long_coder3_dont <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder3_dont", "relfreq_cond2_coder3_dont", "relfreq_cond3_coder3_dont"), "relfreq_coder3_dont")
# Lost in the dialog
long_coder1_lost <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder1_lost", "relfreq_cond2_coder1_lost", "relfreq_cond3_coder1_lost"), "relfreq_coder1_lost")
long_coder2_lost <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder2_lost", "relfreq_cond2_coder2_lost", "relfreq_cond3_coder2_lost"), "relfreq_coder2_lost")
long_coder3_lost <- tranformToLong(dataset,c("pid"), c("relfreq_cond1_coder3_lost", "relfreq_cond2_coder3_lost", "relfreq_cond3_coder3_lost"), "relfreq_coder3_lost")

# merge data into one single wide format
cat("Merge data into one single wide format\n\n")

data_merge <- Reduce(merge_func, list(long_coder1_detail, long_coder2_detail, long_coder3_detail,
                                      long_coder1_normal, long_coder2_normal, long_coder3_normal,
                                      long_coder1_short, long_coder2_short, long_coder3_short,
                                      long_coder1_dont, long_coder2_dont, long_coder3_dont,
                                      long_coder1_lost, long_coder2_lost, long_coder3_lost
                                      ))


cat("Writing long format data frame into file...\n\n")
write.csv(data_merge, "data_long_process.csv", row.names = FALSE)
                       
cat("Data preparation is completed!");

######### stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_prepare_automatic_mechanism_for_measuring_subjective_unit_of_discomfort.txt") 
